<?php declare(strict_types=1);

namespace Everyware\Helpers;

use Everyware\Exceptions\NewRelicLoggerException;
use Exception;

class NewRelicLogger
{
    /**
     * Send error to New Relic if enabled else to log
     */
    public static function logError(string $message, Exception $exception = null): void
    {
        static::logException(
            $exception ?? new NewRelicLoggerException($message),
            $exception instanceof Exception ? $message : null
        );
    }

    public static function logException(Exception $exception, string $message = null): void
    {
        $logger = new static();
        $logger->log($exception, $message);
    }

    public function generateLogMessage(Exception $exception, string $message = null): string
    {
        if ($message !== null) {
            return sprintf('%s: %s', $message, $exception->getMessage());
        }

        return $exception->getMessage();
    }

    public function log(Exception $exception, string $message = null): void
    {
        if ($this->newRelicEnabled()) {
            $this->logToNewRelic($exception, $message);
        }

        /** @noinspection ForgottenDebugOutputInspection */
        error_log($this->generateLogMessage($exception, $message));
    }

    private function newRelicEnabled(): bool
    {
        return extension_loaded('newrelic');
    }

    private function logToNewRelic(Exception $exception, string $message = null): void
    {
        /** @noinspection PhpComposerExtensionStubsInspection */
        newrelic_notice_error($exception, $message);
    }
}
