<?php

namespace Everyware\Storage;

use InvalidArgumentException;

class CacheObject
{
    /**
     * @var int
     */
    private $timestamp;

    /**
     * @var mixed
     */
    private $value;

    public function __construct($value)
    {
        $this->value = $value;
        $this->timestamp = time();
    }

    public function ageExceeds(int $seconds): bool
    {
        return $this->getAgeInSeconds() > $seconds;
    }


    public function decreaseAge(int $seconds): void
    {
        $this->validateAgeInput($seconds);

        $this->timestamp += $seconds;
    }

    public function getAgeInSeconds()
    {
        return time() - $this->timestamp;
    }

    public function getTimestamp(): int
    {
        return $this->timestamp;
    }

    public function getValue()
    {
        return $this->value;
    }

    public function increaseAge(int $seconds): void
    {
        $this->validateAgeInput($seconds);

        $this->timestamp -= $seconds;
    }

    public function resetAge(): void
    {
        $this->timestamp = time();
    }

    public function toArray(): array
    {
        return [
            'timestamp' => $this->getTimestamp(),
            'value' => $this->getValue()
        ];
    }

    private function validateAgeInput(int $seconds): void
    {
        if ($seconds === 0) {
            throw new InvalidArgumentException('Can not change age with zero');
        }

        if ($seconds < 0) {
            throw new InvalidArgumentException('Can not change age with a negative number');
        }
    }
}
