<?php declare(strict_types=1);

namespace Spec\Everyware\Helpers;

use Everyware\Contracts\OcResponseCacheValidator;
use Everyware\Exceptions\InvalidOcResponseException;
use Everyware\Helpers\ContentTypesResponseValidator;
use PhpSpec\ObjectBehavior;
use Spec\DocumentFileLoader;

class ContentTypesResponseValidatorSpec extends ObjectBehavior
{
    public function it_is_initializable(): void
    {
        $this->shouldHaveType(ContentTypesResponseValidator::class);
        $this->shouldImplement(OcResponseCacheValidator::class);
    }

    public function it_should_throw_error_if_the_response_is_empty()
    {
        $this->shouldThrow(InvalidOcResponseException::class)->duringValidateResponse('');
    }

    public function it_should_throw_error_if_the_response_contain_an_empty_contenttypes_property()
    {
        $this->shouldThrow(InvalidOcResponseException::class)->duringValidateResponse('{ "contentTypes": [] }');
    }

    public function it_should_not_throw_error_if_the_response_is_valid()
    {
        $this->shouldNotThrow(InvalidOcResponseException::class)->duringValidateResponse($this->contentTypesResponseJson());
    }

    private function contentTypesResponseJson(): string
    {
        return DocumentFileLoader::loadDocumentJson('full_contenttypes_response.json');
    }
}
